using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

namespace DynamicControlsPlaceholderDemo
{
	public class DynamicControlsPlaceholderDemo : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Button btnRoundtrip;
		protected System.Web.UI.WebControls.Button btnAddLabel;
		protected DBauer.Web.UI.WebControls.DynamicControlsPlaceholder DCP;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			if(!IsPostBack)
			{
				LiteralControl lit = new LiteralControl();
				lit.ID = "Lit1";
				DCP.Controls.Add(lit);
				lit.Text = "Test";

				Label label1 = new Label();
				label1.ID = "Label1";
				DCP.Controls.Add(label1);	//TrackViewState is called implicitly
				label1.Text = "I'll be persisted<br><br>";

				Label label2 = new Label();
				label2.ID = "Label2";
				label2.Text = "I'll be persisted but my property will be lost - so you won't see me<br><br>";
				DCP.Controls.Add(label2);	//TrackViewState is called implicitly => all ViewState entries set before this point are lost

				TextBox tb = new TextBox();
				tb.ID = "TextBox1";
				DCP.Controls.Add(tb);
				tb.AutoPostBack = true;
				tb.TextChanged += new EventHandler(tb_OnTextChanged);

				ArrayList al = new ArrayList();
				al.Add("Test1");
				al.Add("Test2");
				al.Add("Test3");
				al.Add("Test4");

				DataGrid dg = new DataGrid();
				dg.ID = "dg";
				DCP.Controls.Add(dg);
				dg.DataSource = al;
				dg.DataBind();

				ViewState["lblCount"] = 2;

				Control uc1 = Page.LoadControl("Test/Web_UserControl1.ascx");
				uc1.ID = "uc1";
				DCP.Controls.Add(uc1);

				Control uc2 = Page.LoadControl("Test/Test2/Web_UserControl2.ascx");
				uc2.ID = "uc2";
				DCP.Controls.Add(uc2);

				Control uc3 = Page.LoadControl("Web_UserControl3.ascx");
				uc3.ID = "uc3";
				DCP.Controls.Add(uc3);
			}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.DCP.ControlRestored += new DBauer.Web.UI.WebControls.DynamicControlEventHandler(this.DCP_ControlRestored);
			this.DCP.PreRestore += new System.EventHandler(this.DCP_PreRestore);
			this.DCP.PostRestore += new System.EventHandler(this.DCP_PostRestore);
			this.btnRoundtrip.Click += new System.EventHandler(this.btnRoundtrip_Click);
			this.btnAddLabel.Click += new System.EventHandler(this.btnAddLabel_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void tb_OnTextChanged(object sender, System.EventArgs e)
		{
			Trace.Write("TextChanged");
		}

		private void btnRoundtrip_Click(object sender, System.EventArgs e)
		{
		
		}

		private void btnAddLabel_Click(object sender, System.EventArgs e)
		{
			//this method demonstrates that you can add further controls programmatically that are persisted automatically
			int lblCount = (int) ViewState["lblCount"];

			Label label = new Label();
			label.ID = "Label" + (++lblCount).ToString();
			DCP.Controls.Add(label);
			label.Text = "I'll be persisted<br><br>";

			ViewState["lblCount"] = lblCount;
		}

		private void DCP_ControlRestored(object sender, DBauer.Web.UI.WebControls.DynamicControlEventArgs e)
		{
			//the ControlRestored event can be used to reattach event handlers that cannot be persisted automatically
			if(e.DynamicControl.ID == "TextBox1")
				((TextBox) e.DynamicControl).TextChanged += new EventHandler(tb_OnTextChanged);
		}

		private void DCP_PostRestore(object sender, System.EventArgs e)
		{
		}

		private void DCP_PreRestore(object sender, System.EventArgs e)
		{
		
		}
	}
}
